==> ejc-ztpcdc-impl-3.0.0-20230717.145650-123-sources.jar: com/ejianc/business/dc/bean/DcDrwgrpInfoEntity.java <==
package com.ejianc.business.dc.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 卷册信息
 *
 * @author generator
 */
@TableName("dc_drwgrp_info")
public class DcDrwgrpInfoEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "project_id")
    private Long projectId; // 项目ID
    @TableField(value = "project_code")
    private String projectCode; // 项目编码
    @TableField(value = "project_name")
    private String projectName; // 项目名称
    @TableField(value = "bill_state")
    private Integer billState; // 单据状态
    @TableField(value = "drwgrp_code")
    private String drwgrpCode; // 卷册编号
    @TableField(exist = false)
    private String oldDrwgrpCode; // 旧卷册编号
    @TableField(value = "drwgrp_name")
    private String drwgrpName; // 卷册名称
    @TableField(value = "drwgrp_vsn")
    private String drwgrpVsn; // 卷册版本
    @TableField(exist = false)
    private String oldDrwgrpVsn; // 卷册版本
    @TableField(value = "drwgrp_sts")
    private String drwgrpSts; // 卷册状态
    @TableField(value = "drwgrp_num")
    private Integer drwgrpNum; // 卷册套数
    @TableField(value = "surplus_num")
    private Integer surplusNum; // 库存量
    @TableField(value = "source_unitid")
    private Long sourceUnitid; // 来源单位id
    @TableField(value = "source_unitname")
    private String sourceUnitname; // 来源单位名称
    @TableField(value = "drwgrp_type")
    private Long drwgrpType; // 图纸类别--字典dc_drwgrp_type
    @TableField(value = "transfer_code")
    private String transferCode; // 传递单号
    @TableField(value = "draw_arrive_date")
    private Date drawArriveDate; // 到图日期
    @TableField(value = "mgrp")
    private Long mgrp; // 机组--字典pub_mgrp_code
    @TableField(value = "specialty")
    private Long specialty; // 专业--字典pub_specialty_code
    @TableField(value = "sys")
    private Long sys; // 系统--字典pub_system_code
    @TableField(value = "remarks")
    private String remarks; // 备注
    @TableField(value = "issue_sts")
    private String issueSts; // 签发状态
    @TableField(value = "issue_user_code")
    private String issueUserCode; // 签发人编号
    @TableField(value = "issue_user_name")
    private String issueUserName; // 签发人姓名
    @TableField(value = "create_dept_id")
    private Long createDeptId; // 创建部门id
    @TableField(value = "org_id")
    private Long orgId; // 所属组织id
    @TableField(value = "org_code")
    private String orgCode; // 组织编码
    @TableField(value = "org_name")
    private String orgName; // 组织名称
    @TableField(value = "parent_org_id")
    private Long parentOrgId; // 所属组织
    @TableField(value = "parent_org_code")
    private String parentOrgCode; // 所属组织编码
    @TableField(value = "parent_org_name")
    private String parentOrgName; // 所属组织名称
    @TableField(value = "issue_date")
    private Date issueDate; // 签发日期

    @TableField(exist = false)
    @SubEntity(serviceName = "dcDrawInfoService", pidName = "drwgrpId")
    private List<DcDrawInfoEntity> dcDrawInfoEntityList = new ArrayList<>();

    @TableField(exist = false)
    private List<DcDrawdistributeRecordEntity> dcDrawdistributeRecordList = new ArrayList<>();

    public List<DcDrawdistributeRecordEntity> getDcDrawdistributeRecordEntityList() {
        return dcDrawdistributeRecordList;
    }

    public void setDcDrawdistributeRecordEntityList(List<DcDrawdistributeRecordEntity> dcDrawdistributeRecordList) {
        this.dcDrawdistributeRecordList = dcDrawdistributeRecordList;
    }

    public List<DcDrawInfoEntity> getDcDrawInfoEntityList() {
        return dcDrawInfoEntityList;
    }

    public String getOldDrwgrpCode() {
        return oldDrwgrpCode;
    }

    public void setOldDrwgrpCode(String oldDrwgrpCode) {
        this.oldDrwgrpCode = oldDrwgrpCode;
    }

    public String getOldDrwgrpVsn() {
        return oldDrwgrpVsn;
    }

    public void setOldDrwgrpVsn(String oldDrwgrpVsn) {
        this.oldDrwgrpVsn = oldDrwgrpVsn;
    }

    public void setDcDrawInfoEntityList(List<DcDrawInfoEntity> dcDrawInfoEntityList) {
        this.dcDrawInfoEntityList = dcDrawInfoEntityList;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getDrwgrpCode() {
        return drwgrpCode;
    }

    public void setDrwgrpCode(String drwgrpCode) {
        this.drwgrpCode = drwgrpCode;
    }

    public String getDrwgrpName() {
        return drwgrpName;
    }

    public void setDrwgrpName(String drwgrpName) {
        this.drwgrpName = drwgrpName;
    }

    public String getDrwgrpVsn() {
        return drwgrpVsn;
    }

    public void setDrwgrpVsn(String drwgrpVsn) {
        this.drwgrpVsn = drwgrpVsn;
    }

    public String getDrwgrpSts() {
        return drwgrpSts;
    }

    public void setDrwgrpSts(String drwgrpSts) {
        this.drwgrpSts = drwgrpSts;
    }

    public Integer getDrwgrpNum() {
        return drwgrpNum;
    }

    public void setDrwgrpNum(Integer drwgrpNum) {
        this.drwgrpNum = drwgrpNum;
    }

    public Integer getSurplusNum() {
        return surplusNum;
    }

    public void setSurplusNum(Integer surplusNum) {
        this.surplusNum = surplusNum;
    }

    public Long getSourceUnitid() {
        return sourceUnitid;
    }

    public void setSourceUnitid(Long sourceUnitid) {
        this.sourceUnitid = sourceUnitid;
    }

    public String getSourceUnitname() {
        return sourceUnitname;
    }

    public void setSourceUnitname(String sourceUnitname) {
        this.sourceUnitname = sourceUnitname;
    }

    public Long getDrwgrpType() {
        return drwgrpType;
    }

    public void setDrwgrpType(Long drwgrpType) {
        this.drwgrpType = drwgrpType;
    }

    public String getTransferCode() {
        return transferCode;
    }

    public void setTransferCode(String transferCode) {
        this.transferCode = transferCode;
    }

    public Date getDrawArriveDate() {
        return drawArriveDate;
    }

    public void setDrawArriveDate(Date drawArriveDate) {
        this.drawArriveDate = drawArriveDate;
    }

    public Long getMgrp() {
        return mgrp;
    }

    public void setMgrp(Long mgrp) {
        this.mgrp = mgrp;
    }

    public Long getSpecialty() {
        return specialty;
    }

    public void setSpecialty(Long specialty) {
        this.specialty = specialty;
    }

    public Long getSys() {
        return sys;
    }

    public void setSys(Long sys) {
        this.sys = sys;
    }

    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }

    public String getIssueSts() {
        return issueSts;
    }

    public void setIssueSts(String issueSts) {
        this.issueSts = issueSts;
    }

    public String getIssueUserCode() {
        return issueUserCode;
    }

    public void setIssueUserCode(String issueUserCode) {
        this.issueUserCode = issueUserCode;
    }

    public String getIssueUserName() {
        return issueUserName;
    }

    public void setIssueUserName(String issueUserName) {
        this.issueUserName = issueUserName;
    }

    public Long getCreateDeptId() {
        return createDeptId;
    }

    public void setCreateDeptId(Long createDeptId) {
        this.createDeptId = createDeptId;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public Date getIssueDate() {
        return issueDate;
    }

    public void setIssueDate(Date issueDate) {
        this.issueDate = issueDate;
    }

}

==> ejc-ztpcdc-impl-3.0.0-20230802.031119-153-sources.jar: com/ejianc/business/dc/bean/DcDrwgrpInfoEntity.java <==
package com.ejianc.business.dc.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 卷册信息
 *
 * @author generator
 */
@TableName("dc_drwgrp_info")
public class DcDrwgrpInfoEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "project_id")
    private Long projectId; // 项目ID
    @TableField(value = "project_code")
    private String projectCode; // 项目编码
    @TableField(value = "project_name")
    private String projectName; // 项目名称
    @TableField(value = "bill_state")
    private Integer billState; // 单据状态
    @TableField(value = "drwgrp_code")
    private String drwgrpCode; // 卷册编号
    @TableField(exist = false)
    private String oldDrwgrpCode; // 旧卷册编号
    @TableField(value = "drwgrp_name")
    private String drwgrpName; // 卷册名称
    @TableField(value = "drwgrp_vsn")
    private String drwgrpVsn; // 卷册版本
    @TableField(exist = false)
    private String oldDrwgrpVsn; // 卷册版本
    @TableField(value = "drwgrp_sts")
    private String drwgrpSts; // 卷册状态
    @TableField(value = "drwgrp_num")
    private Integer drwgrpNum; // 卷册套数
    @TableField(value = "surplus_num")
    private Integer surplusNum; // 库存量
    @TableField(value = "source_unitid")
    private Long sourceUnitid; // 来源单位id
    @TableField(value = "source_unitname")
    private String sourceUnitname; // 来源单位名称
    @TableField(value = "drwgrp_type")
    private Long drwgrpType; // 图纸类别--字典dc_drwgrp_type
    @TableField(value = "transfer_code")
    private String transferCode; // 传递单号
    @TableField(value = "draw_arrive_date")
    private Date drawArriveDate; // 到图日期
    @TableField(value = "mgrp")
    private Long mgrp; // 机组--字典pub_mgrp_code
    @TableField(value = "specialty")
    private Long specialty; // 专业--字典pub_specialty_code
    @TableField(value = "sys")
    private Long sys; // 系统--字典pub_system_code
    @TableField(value = "remarks")
    private String remarks; // 备注
    @TableField(value = "issue_sts")
    private String issueSts; // 签发状态
    @TableField(value = "issue_user_code")
    private String issueUserCode; // 签发人编号
    @TableField(value = "issue_user_name")
    private String issueUserName; // 签发人姓名
    @TableField(value = "create_dept_id")
    private Long createDeptId; // 创建部门id
    @TableField(value = "org_id")
    private Long orgId; // 所属组织id
    @TableField(value = "org_code")
    private String orgCode; // 组织编码
    @TableField(value = "org_name")
    private String orgName; // 组织名称
    @TableField(value = "parent_org_id")
    private Long parentOrgId; // 所属组织
    @TableField(value = "parent_org_code")
    private String parentOrgCode; // 所属组织编码
    @TableField(value = "parent_org_name")
    private String parentOrgName; // 所属组织名称
    @TableField(value = "issue_date")
    private Date issueDate; // 签发日期
    @TableField(value="engineering_type_id")
    private Long engineeringTypeId; // 工程类别
    @TableField(value="subitem")
    private Long subitem; // 子项--字典zx
    @TableField(value="flow_state")
    private String flowState; // 流程状态--字典dc_tzk
    @TableField(value="specialty_name")
    private String specialtyName; // 专业名称
    @TableField(value="sys_name")
    private String sysName; // 系统名称
    @TableField(value="subitem_name")
    private String subitemName; // 子项名称
    @TableField(value="flow_state_name")
    private String flowStateName; // 流程状态名称

    @TableField(exist = false)
    @SubEntity(serviceName = "dcDrawInfoService", pidName = "drwgrpId")
    private List<DcDrawInfoEntity> dcDrawInfoEntityList = new ArrayList<>();

    @TableField(exist = false)
    private List<DcDrawdistributeRecordEntity> dcDrawdistributeRecordList = new ArrayList<>();

    public List<DcDrawdistributeRecordEntity> getDcDrawdistributeRecordEntityList() {
        return dcDrawdistributeRecordList;
    }

    public void setDcDrawdistributeRecordEntityList(List<DcDrawdistributeRecordEntity> dcDrawdistributeRecordList) {
        this.dcDrawdistributeRecordList = dcDrawdistributeRecordList;
    }

    public List<DcDrawInfoEntity> getDcDrawInfoEntityList() {
        return dcDrawInfoEntityList;
    }

    public String getOldDrwgrpCode() {
        return oldDrwgrpCode;
    }

    public void setOldDrwgrpCode(String oldDrwgrpCode) {
        this.oldDrwgrpCode = oldDrwgrpCode;
    }

    public String getOldDrwgrpVsn() {
        return oldDrwgrpVsn;
    }

    public void setOldDrwgrpVsn(String oldDrwgrpVsn) {
        this.oldDrwgrpVsn = oldDrwgrpVsn;
    }

    public void setDcDrawInfoEntityList(List<DcDrawInfoEntity> dcDrawInfoEntityList) {
        this.dcDrawInfoEntityList = dcDrawInfoEntityList;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getDrwgrpCode() {
        return drwgrpCode;
    }

    public void setDrwgrpCode(String drwgrpCode) {
        this.drwgrpCode = drwgrpCode;
    }

    public String getDrwgrpName() {
        return drwgrpName;
    }

    public void setDrwgrpName(String drwgrpName) {
        this.drwgrpName = drwgrpName;
    }

    public String getDrwgrpVsn() {
        return drwgrpVsn;
    }

    public void setDrwgrpVsn(String drwgrpVsn) {
        this.drwgrpVsn = drwgrpVsn;
    }

    public String getDrwgrpSts() {
        return drwgrpSts;
    }

    public void setDrwgrpSts(String drwgrpSts) {
        this.drwgrpSts = drwgrpSts;
    }

    public Integer getDrwgrpNum() {
        return drwgrpNum;
    }

    public void setDrwgrpNum(Integer drwgrpNum) {
        this.drwgrpNum = drwgrpNum;
    }

    public Integer getSurplusNum() {
        return surplusNum;
    }

    public void setSurplusNum(Integer surplusNum) {
        this.surplusNum = surplusNum;
    }

    public Long getSourceUnitid() {
        return sourceUnitid;
    }

    public void setSourceUnitid(Long sourceUnitid) {
        this.sourceUnitid = sourceUnitid;
    }

    public String getSourceUnitname() {
        return sourceUnitname;
    }

    public void setSourceUnitname(String sourceUnitname) {
        this.sourceUnitname = sourceUnitname;
    }

    public Long getDrwgrpType() {
        return drwgrpType;
    }

    public void setDrwgrpType(Long drwgrpType) {
        this.drwgrpType = drwgrpType;
    }

    public String getTransferCode() {
        return transferCode;
    }

    public void setTransferCode(String transferCode) {
        this.transferCode = transferCode;
    }

    public Date getDrawArriveDate() {
        return drawArriveDate;
    }

    public void setDrawArriveDate(Date drawArriveDate) {
        this.drawArriveDate = drawArriveDate;
    }

    public Long getMgrp() {
        return mgrp;
    }

    public void setMgrp(Long mgrp) {
        this.mgrp = mgrp;
    }

    public Long getSpecialty() {
        return specialty;
    }

    public void setSpecialty(Long specialty) {
        this.specialty = specialty;
    }

    public Long getSys() {
        return sys;
    }

    public void setSys(Long sys) {
        this.sys = sys;
    }

    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }

    public String getIssueSts() {
        return issueSts;
    }

    public void setIssueSts(String issueSts) {
        this.issueSts = issueSts;
    }

    public String getIssueUserCode() {
        return issueUserCode;
    }

    public void setIssueUserCode(String issueUserCode) {
        this.issueUserCode = issueUserCode;
    }

    public String getIssueUserName() {
        return issueUserName;
    }

    public void setIssueUserName(String issueUserName) {
        this.issueUserName = issueUserName;
    }

    public Long getCreateDeptId() {
        return createDeptId;
    }

    public void setCreateDeptId(Long createDeptId) {
        this.createDeptId = createDeptId;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public Date getIssueDate() {
        return issueDate;
    }

    public void setIssueDate(Date issueDate) {
        this.issueDate = issueDate;
    }

    public Long getEngineeringTypeId() {
        return engineeringTypeId;
    }

    public void setEngineeringTypeId(Long engineeringTypeId) {
        this.engineeringTypeId = engineeringTypeId;
    }

    public Long getSubitem() {
        return subitem;
    }

    public void setSubitem(Long subitem) {
        this.subitem = subitem;
    }

    public String getFlowState() {
        return flowState;
    }

    public void setFlowState(String flowState) {
        this.flowState = flowState;
    }

    public String getSpecialtyName() {
        return specialtyName;
    }

    public void setSpecialtyName(String specialtyName) {
        this.specialtyName = specialtyName;
    }

    public String getSysName() {
        return sysName;
    }

    public void setSysName(String sysName) {
        this.sysName = sysName;
    }

    public String getSubitemName() {
        return subitemName;
    }

    public void setSubitemName(String subitemName) {
        this.subitemName = subitemName;
    }

    public String getFlowStateName() {
        return flowStateName;
    }

    public void setFlowStateName(String flowStateName) {
        this.flowStateName = flowStateName;
    }
}
